Struct diem_wallet::Mnemonic[][src]

pub struct Mnemonic(_);
Mnemonic seed for deterministic key derivation based on BIP39. The mnemonic must encode entropy in a multiple of 32 bits. With more entropy, security is improved but the number of words increases.

The allowed sizes of entropy are 128, 160, 192, 224 and 256 bits as shown in the following table.

+———+—––+ | ENTROPY | WORDS | +———+—––+ | 128 | 12 | | 160 | 15 | | 192 | 18 | | 224 | 21 | | 256 | 24 | +———+—––+

Implementations

Generate mnemonic from string.

Generate mnemonic from entropy byte-array.

Write mnemonic to output_file_path.

Read mnemonic from input_file_path.